import logging
from Products.CMFCore.utils import getToolByName

log = logging.getLogger('babble.demo/setuphandlers.py')

def add_chat_service(context):
    if context.readDataFile("babble.demo_marker.txt") is None:
        return

    root = context.getSite().aq_parent
    view = root.unrestrictedTraverse('+/addChatService.html')
    view(add_input_name='chatservice', title='Chat Service', submit_add=1)


def configure_chat_tool(context):
    """ Configure the chat_service to point to the correct URL"""
    if context.readDataFile("babble.demo_marker.txt") is None:
        return

    site = context.getSite()
    portal_chat = getToolByName(site, 'portal_chat')
    portal_chat._updateProperty('name', 'chatservice')
    portal_chat._updateProperty('host', 'localhost')
    portal_chat._updateProperty('port', '8081')
    portal_chat._updateProperty('username', 'admin')
    portal_chat._updateProperty('password', 'admin')





from setuptools import setup, find_packages
import os

version = '0.2'

setup(
    name='babble.demo',
    version=version,
    description="Creates a demo Babble instant messaging setup for Plone",
    long_description=open("README.txt").read() + "\n" +
                    open(os.path.join("docs", "HISTORY.txt")).read(),
    # Get more strings from
    # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
    "Framework :: Plone",
    "Programming Language :: Python",
    ],
    keywords='babble messaging demo plone',
    author='JC Brand',
    author_email='brand@syslab.com',
    url='http://svn.plone.org/svn/collective/',
    license='GPL',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['babble'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'actionbar.babble',
    ],
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
    setup_requires=["PasteScript"],
    paster_plugins=["ZopeSkel"],
    )
